@@ -381,7 +381,7 @@ public:
 #else
     template <typename T, detail::enable_if_t<is_real128_interoperable<T>::value, int> = 0>
 #endif
-    constexpr explicit real128(const T &x) : m_value(cast_to_float128(x))
+    constexpr real128(const T &x) : m_value(cast_to_float128(x))
     {
     }
     // Constructor from std::complex.
@@ -792,6 +792,13 @@ public:
     {
         return *this = mppp::abs(*this);
     }
+#if !defined(__INTEL_COMPILER)
+    MPPP_CONSTEXPR_14
+#endif
+    real128 &fabs()
+    {
+        return this->abs();
+    }
 
     // In-place roots.
     real128 &sqrt();
@@ -887,6 +894,17 @@ constexpr
                : (x.fpclassify() == FP_ZERO ? real128{} : (x.m_value < 0 ? real128{-x.m_value} : x));
 }
 
+#if defined(__INTEL_COMPILER)
+inline
+#else
+constexpr
+#endif
+    real128
+    fabs(const real128 &x)
+{
+    return mppp::abs(x);
+}
+
 // Multiply by power of 2.
 MPPP_DLL_PUBLIC real128 scalbn(const real128 &, int);
 MPPP_DLL_PUBLIC real128 scalbln(const real128 &, long);
